@@ -3,7 +3,7 @@
 # @Date:   2020-03-08 14:34:45
 # @E-mail: maoyongfan@163.com
 # @Last Modified by:   yongfanmao
-# @Last Modified time: 2020-10-28 19:17:47
+# @Last Modified time: 2020-11-03 11:28:52
 
 __version__ = "1.0"
 
@@ -38,7 +38,10 @@ class Request(object):
 					try:
 						kwargs['data']=eval(kwargs['data'])
 					except:
-						raise Exception("请求data数据格式不对")
+						try:
+							kwargs['data']= json.loads(kwargs['data'])
+						except:	
+							raise Exception("请求data数据格式不对")
 
 			# 需加密http请求
 			if "encode" in kwargs and kwargs['encode']:
